@@ -232,7 +232,7 @@ gboolean quit_game_cb(GtkWidget *widget, gpointer data)
                                  GTK_DIALOG_MODAL,
                                  GTK_MESSAGE_QUESTION,
                                  GTK_BUTTONS_NONE,
-                                 _("Do you really want to quit?"));
+                                 _("Really exit Gataxx?"));
     gtk_dialog_add_buttons (GTK_DIALOG (box),
             GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
             GTK_STOCK_QUIT, GTK_RESPONSE_ACCEPT,
